@@ -3,13 +3,25 @@
 # convenient Python types.
 
 import ephem._libastro as _libastro
+import re
 from datetime import datetime as _datetime
 from datetime import timedelta as _timedelta
 from datetime import tzinfo as _tzinfo
 from math import pi
 from time import localtime as _localtime
 
-__version__ = '4.0.0.1'
+__version__ = '4.1'
+
+# As a favor, compile a regular expression that our C library would
+# really rather not compile for itself.
+
+_libastro._scansexa_split = re.compile(r'''
+    \s*:\s*         # A colon optionally surrounded by whitespace,
+    |               # or,
+    (?<!^)\s+(?!$)  # whitespace not at the start or end of the string.
+''', re.X).split
+
+# Various constants.
 
 twopi = pi * 2.
 halfpi = pi / 2.
@@ -239,6 +251,9 @@ class NeverUpError(CircumpolarError): pass
 class AlwaysUpError(CircumpolarError): pass
 
 def describe_riset_search(method):
+    if method.__doc__ is None:
+        return method
+
     method.__doc__ += """, returning its date.
 
     The search starts at the `date` of this `Observer` and is limited to
@@ -285,6 +300,8 @@ class Observer(_libastro.Observer):
         o.pressure = self.pressure
         return o
 
+    __copy__ = copy
+
     def __repr__(self):
         """Return a useful textual representation of this Observer."""
         return ('<ephem.Observer date=%r epoch=%r'
